about summary refs log tree commit diff
path: root/sysdeps/unix/sysv/linux/x86/bits
diff options
context:
space:
mode:
authorAlistair Francis <alistair.francis@wdc.com>2020-02-25 15:52:59 -0800
committerAlistair Francis <alistair.francis@wdc.com>2020-04-29 08:29:30 -0700
commit05332ac38b245c1983b306aa6909abfc48988a5f (patch)
treee364533b63e5c5a36d62b0a14bcbd76fe31f80c8 /sysdeps/unix/sysv/linux/x86/bits
parent246a53d3c6aeb4ab03b5dc83144207bc6a916011 (diff)
downloadglibc-05332ac38b245c1983b306aa6909abfc48988a5f.tar.gz
glibc-05332ac38b245c1983b306aa6909abfc48988a5f.tar.xz
glibc-05332ac38b245c1983b306aa6909abfc48988a5f.zip
semctl: Remove the sem-pad.h file
Remove the sem-pad.h file and instead have architectures override the
struct semid_ds via the bits/types/struct_semid_ds.h file.

Reviewed-by: Adhemerval Zanella <adhemerval.zanella@linaro.org>
Diffstat (limited to 'sysdeps/unix/sysv/linux/x86/bits')
-rw-r--r--sysdeps/unix/sysv/linux/x86/bits/types/struct_semid_ds.h (renamed from sysdeps/unix/sysv/linux/x86/bits/sem-pad.h)20
1 files changed, 15 insertions, 5 deletions
diff --git a/sysdeps/unix/sysv/linux/x86/bits/sem-pad.h b/sysdeps/unix/sysv/linux/x86/bits/types/struct_semid_ds.h
index 102e226997..f7ec89d115 100644
--- a/sysdeps/unix/sysv/linux/x86/bits/sem-pad.h
+++ b/sysdeps/unix/sysv/linux/x86/bits/types/struct_semid_ds.h
@@ -1,5 +1,5 @@
-/* Define where padding goes in struct semid_ds.  x86 version.
-   Copyright (C) 2018-2020 Free Software Foundation, Inc.
+/* x86 implementation of the semaphore struct semid_ds.
+   Copyright (C) 1995-2020 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -17,8 +17,18 @@
    <https://www.gnu.org/licenses/>.  */
 
 #ifndef _SYS_SEM_H
 # error "Never use <bits/sem-pad.h> directly; include <sys/sem.h> instead."
 #endif
 
-#define __SEM_PAD_AFTER_TIME 1
-#define __SEM_PAD_BEFORE_TIME 0
+/* Data structure describing a set of semaphores.  */
+struct semid_ds
+{
+  struct ipc_perm sem_perm;   /* operation permission struct */
+  __time_t sem_otime;  /* last semop() time */
+  __syscall_ulong_t __glibc_reserved1;
+  __time_t sem_ctime;  /* last time changed by semctl() */
+  __syscall_ulong_t __glibc_reserved2;
+  __syscall_ulong_t sem_nsems;    /* number of semaphores in set */
+  __syscall_ulong_t __glibc_reserved3;
+  __syscall_ulong_t __glibc_reserved4;
+};
@@ -17,8 +17,18 @@
 
 #ifndef _SYS_SEM_H
-# error "Never use <bits/sem-pad.h> directly; include <sys/sem.h> instead."
+# error "Never include <bits/types/struct_semid_ds.h> directly; use <sys/sem.h> instead."
 #endif
 